@@ -1,5 +1,4 @@
 from robotidy.cli import cli
 
-
-if __name__ == '__main__':
+if __name__ == "__main__":
     cli()
