@@ -1,6 +1,4 @@
-from itertools import takewhile
-
-from robot.api.parsing import ModelTransformer, Token
+from robot.api.parsing import KeywordCall, ModelTransformer, Token
 
 try:
     from robot.api.parsing import InlineIfHeader
@@ -114,17 +112,9 @@ class NormalizeSeparators(ModelTransformer):
             return node
         self.is_inline = InlineIfHeader and isinstance(node.header, InlineIfHeader)
         self.visit_Statement(node.header)
-        indent = 1
-        if self.is_inline:
-            indent = self.indent
-            self.indent = 1
-        else:
-            self.indent += 1
+        self.indent += 1
         node.body = [self.visit(item) for item in node.body]
-        if self.is_inline:
-            self.indent = indent
-        else:
-            self.indent -= 1
+        self.indent -= 1
         if node.orelse:
             self.visit(node.orelse)
         if node.end:
@@ -138,6 +128,9 @@ class NormalizeSeparators(ModelTransformer):
             return self._handle_spaces(doc, has_pipes, only_indent=True)
         return self.visit_Statement(doc)
 
+    def is_keyword_inside_inline_if(self, node):
+        return self.is_inline and isinstance(node, KeywordCall)
+
     @skip_if_disabled
     def visit_Statement(self, statement):  # noqa
         has_pipes = statement.tokens[0].value.startswith("|")
@@ -152,7 +145,7 @@ class NormalizeSeparators(ModelTransformer):
                     if prev_sep:
                         continue
                     prev_sep = True
-                    if index == 0:
+                    if index == 0 and not self.is_keyword_inside_inline_if(statement):
                         token.value = self.formatting_config.indent * self.indent
                     elif not only_indent:
                         token.value = self.formatting_config.separator
