@@ -61,7 +61,7 @@ class NormalizeTags(ModelTransformer):
         if indent:
             tag_node = tag_class.from_params(
                 tags,
-                indent=self.formatting_config.separator,
+                indent=self.formatting_config.indent,
                 separator=self.formatting_config.separator,
             )
         else:
