@@ -9,33 +9,35 @@ class OrderTags(ModelTransformer):
 
     Tags are ordered in lexicographic order like this:
 
-        *** Test Cases ***
-        Tags Upper Lower
-            [Tags]    ba    Ab    Bb    Ca    Cb    aa
-            My Keyword
-
-        *** Keywords ***
+    ```robotframework
+    *** Test Cases ***
+    Tags Upper Lower
+        [Tags]    ba    Ab    Bb    Ca    Cb    aa
         My Keyword
-            [Tags]    ba    Ab    Bb    Ca    Cb    aa
-            No Operation
+
+    *** Keywords ***
+    My Keyword
+        [Tags]    ba    Ab    Bb    Ca    Cb    aa
+        No Operation
+    ```
 
     To:
 
-        *** Test Cases ***
-        Tags Upper Lower
-            [Tags]    aa    Ab    ba    Bb    Ca    Cb
-            My Keyword
-
-        *** Keywords ***
+    ```robotframework
+    *** Test Cases ***
+    Tags Upper Lower
+        [Tags]    aa    Ab    ba    Bb    Ca    Cb
         My Keyword
-            [Tags]    aa    Ab    ba    Bb    Ca    Cb
-            No Operation
+
+    *** Keywords ***
+    My Keyword
+        [Tags]    aa    Ab    ba    Bb    Ca    Cb
+        No Operation
+    ```
 
     Default order can be changed using following parameters:
       - ``case_sensitive = False``
       - ``reverse = False``
-
-    See https://robotidy.readthedocs.io/en/latest/transformers/OrderTags.html for more examples.
     """
 
     ENABLED = False
