@@ -1,15 +1,7 @@
-from robot.api.parsing import (
-    Token,
-    ModelTransformer,
-    End,
-    If,
-    IfHeader,
-    ElseHeader,
-    ElseIfHeader,
-    KeywordCall,
-)
-from robotidy.utils import normalize_name, after_last_dot
-from robotidy.decorators import check_start_end_line
+from robot.api.parsing import ElseHeader, ElseIfHeader, End, If, IfHeader, KeywordCall, ModelTransformer, Token
+
+from robotidy.disablers import skip_if_disabled, skip_section_if_disabled
+from robotidy.utils import after_last_dot, normalize_name
 
 
 def insert_separators(indent, tokens, separator):
@@ -27,13 +19,20 @@ class ReplaceRunKeywordIf(ModelTransformer):
 
     Following code:
 
+    ```robotframework
+    *** Keywords ***
+    Keyword
         Run Keyword If  ${condition}
         ...  Keyword  ${arg}
         ...  ELSE IF  ${condition2}  Keyword2
         ...  ELSE  Keyword3
+    ```
 
     Will be transformed to:
 
+    ```robotframework
+    *** Keywords ***
+    Keyword
         IF    ${condition}
             Keyword    ${arg}
         ELSE IF    ${condition2}
@@ -41,36 +40,55 @@ class ReplaceRunKeywordIf(ModelTransformer):
         ELSE
             Keyword3
         END
+    ```
 
-    Any return value will be applied to every ELSE/ELSE IF branch:
+    Any return value will be applied to every ``ELSE``/``ELSE IF`` branch:
 
+    ```robotframework
+    *** Keywords ***
+    Keyword
         ${var}  Run Keyword If  ${condition}  Keyword  ELSE  Keyword2
+    ```
 
     Output:
 
+    ```robotframework
+    *** Keywords ***
+    Keyword
         IF    ${condition}
             ${var}    Keyword
         ELSE
             ${var}    Keyword2
         END
+    ```
 
     Run Keywords inside Run Keyword If will be split into separate keywords:
 
-       Run Keyword If  ${condition}  Run Keywords  Keyword  ${arg}  AND  Keyword2
+    ```robotframework
+    *** Keywords ***
+    Keyword
+        Run Keyword If  ${condition}  Run Keywords  Keyword  ${arg}  AND  Keyword2
+    ```
 
     Output:
 
+    ```robotframework
+    *** Keywords ***
+    Keyword
         IF    ${condition}
             Keyword    ${arg}
             Keyword2
         END
+    ```
 
     Supports global formatting params: ``--spacecount``, ``--separator``, ``--startline`` and ``--endline``.
-
-    See https://robotidy.readthedocs.io/en/latest/transformers/ReplaceRunKeywordIf.html for more examples.
     """
 
-    @check_start_end_line
+    @skip_section_if_disabled
+    def visit_Section(self, node):  # noqa
+        return self.generic_visit(node)
+
+    @skip_if_disabled
     def visit_KeywordCall(self, node):  # noqa
         if not node.keyword:
             return node
